bayespy.inference.vmp.nodes.wishart.WishartDistribution.compute_logpdf
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartDistribution.compute_logpdf